@@ -48,8 +48,8 @@ starts_with <- function(vars, match, ignore.case = TRUE) {
 #' @examples 
 #' \dontrun{ 
 #' library(GerminaR)
-#' dt <- GerminaR
-#' dm <- evalDays(evalName = "Ev", data = dt)
+#' dt <- prosopis
+#' dm <- evalDays(evalName = "D", data = dt)
 #' dm
 #' }
 
@@ -71,8 +71,8 @@ evalDays <- function(evalName, data){
 #' @examples 
 #' \dontrun{ 
 #' library(GerminaR)
-#' dt <- GerminaR
-#' dm <- evalFactor(evalName = "Ev", data = dt)
+#' dt <- prosopis
+#' dm <- evalFactor(evalName = "D", data = dt)
 #' dm
 #' }
 
@@ -80,7 +80,7 @@ evalFactor <- function(evalName, data){
   
   evf <- dplyr::select(data, -starts_with(colnames(data), evalName))
   
-  evf[,colnames(evf)] <- lapply(evf[,colnames(evf)] , as.character)
+  #evf[,colnames(evf)] <- lapply(evf[,colnames(evf)] , as.character)
   
   evf
   
@@ -95,23 +95,7 @@ evalFactor <- function(evalName, data){
 #' @importFrom dplyr mutate select rename group_by_ summarise full_join
 #' @importFrom tidyr separate
 #' @export
-# @examples 
-# 
-# \dontrun{
-# library(GerminaR)
-# library(agricolae)
-# library(ggplot2)
-# 
-# dt <- GerminaR
-# sm <- ger_summary(SeedN = "NSeeds", evalName = "Ev", data = dt)
-# 
-# av <- aov(MGT ~ Genotype*Salt, sm)
-# summary(av)
-# mc <- SNK.test(av, c("Genotype", "Salt"))
-# 
-# gr <- dtsm(mc)
-# gr
-# 
+
 dtsm <- function(meanComp){
   
   #to avoid no bisible global variable function
@@ -141,9 +125,97 @@ dtsm <- function(meanComp){
 
 
 
+#' Multiple comparison test
+#'
+#' @description Function analisis of variance for summary data.
+#' @param aov lm o aov result function.
+#' @param comp treatments will be compared.
+#' @param type method for made comparision analysis: c("snk", "tukey", "duncan").
+#' @param sig significance level. Default 0.05
+#' @return Table with complete data for graphics
+#' @importFrom agricolae SNK.test HSD.test duncan.test
+#' @export
 
 
+ger_testcomp <- function( aov, comp, type = "snk", sig = 0.05){
+  
+  if( type == "snk"){
+    
+    mc <- agricolae::SNK.test(y = aov, trt = comp, alpha = sig)
+    
+  } else if (type == "tukey"){
+    
+    mc <- agricolae::HSD.test(y = aov, trt = comp, alpha = sig)
+    
+  } else if (type == "duncan"){
+    
+    mc <- agricolae::duncan.test(y = aov, trt = comp, alpha = sig)
+    
+  }
+  
+  GerminaR::dtsm(mc)
+  
+}
 
 
+#' Regresion line equation
+#'
+#' @description Construc the regression line equation
+#' @param data dataframe with the information
+#' @param y variable in the y axis
+#' @param x variable in the x axis
+#' @return regression equation
+#' @importFrom stats as.formula coef
+#' @export
+
+ger_leq <- function(x, y, data){
+  
+  fml <- as.formula(paste( x , y, sep = " ~ "))
+  mdl <- lm(fml, data)
+  
+  eq <- as.character(as.expression(
+    substitute(italic(y) == a + (b) * italic(x) * "," ~~ italic(R)^2 ~ "=" ~ r2,
+               list(a = format(coef(mdl)[1], digits=2), b = format(coef(mdl)[2], digits=2),
+                    r2 = format(summary(mdl)$r.squared, digits=3) ))))
+  
+  eq
+  
+  # eq <- substitute(italic(y) == a + b %.% italic(x)*","~~italic(R)^2~"="~r2,
+  #                  list(a = format(coef(mdl)[1], digits = 2),
+  #                       b = format(coef(mdl)[2], digits = 2),
+  #                       r2 = format(summary(mdl)$r.squared, digits = 3)))
+  # as.character(as.expression(eq))
+  
+  
+}
+
+
+#' Import google spreadsheet or xlsx file
+#'
+#' @description function to import information from google spreadsheet or xlsx file.
+#' @param dir local file directory for xlsx document or url from google spreadsheet
+#' @param sheet if is a xlsx file, you can choose the sheet number
+#' @return data frame
+#' @importFrom gsheet gsheet2tbl
+#' @importFrom readxl read_excel
+#' @importFrom dplyr  '%>%'
+#' @export
+
+ger_getdata <- function(dir, sheet = 1) {
+  
+  
+  if (file.exists(dir) == TRUE) {
+    
+    readxl::read_excel(path = dir, sheet = sheet) %>% as.data.frame()
+    
+  } else{
+    
+    gsheet::gsheet2tbl(url = dir) %>% as.data.frame()
+    
+  }
+  
+  
+}
+
 
 
